@@ -3,8 +3,8 @@ from typing import Any
 from logger_local.MetaLogger import MetaLogger
 from mysql.connector.cursor import MySQLCursor
 from mysql import connector
-from .constants import LOGGER_CONNECTOR_CODE_OBJECT
-from python_sdk_remote.utilities import our_get_env
+from .constants_src import LOGGER_CONNECTOR_CODE_OBJECT
+# from python_sdk_remote.utilities import our_get_env
 
 # MYSQL_VERSION = our_get_env("MYSQL_VERSION", raise_if_not_found=False)
 # TODO Is it the MySQL engine version or the connector version?
@@ -23,17 +23,21 @@ class Cursor(metaclass=MetaLogger, object=LOGGER_CONNECTOR_CODE_OBJECT):
 
     # TODO: If environment <> prod1 and dvlp1 break down using 3rd party package and analyze the formatted_sql
     #  and call private method _validate_select_table_name(table_name)
-    def execute(self, sql_statement: str, sql_parameters: tuple or list = None, multi: bool = False) -> None:
+    def execute(self, sql_statement: str, sql_parameters: tuple | list = None, multi: bool = False) -> None:
         # TODO: validate_select_table_name(table_name)
         if sql_parameters:
-            quoted_parameters = tuple("'" + str(param) + "'" for param in sql_parameters)
+            quoted_parameters = tuple(
+                "'" + str(param) + "'" for param in sql_parameters)
             formatted_sql = sql_statement % quoted_parameters
             sql_parameters_str = ", ".join(quoted_parameters)
         else:
             formatted_sql = sql_statement
             sql_parameters_str = "None"
+
+        formatted_sql = ' '.join(formatted_sql.split())
+
         self.logger.info(object={
-            "formatted_sql": formatted_sql.replace("\n", " "),
+            "formatted_sql": formatted_sql,
             "sql_parameters": sql_parameters_str,
             "sql_statement": sql_statement.replace("\n", " ")
         })
@@ -42,7 +46,7 @@ class Cursor(metaclass=MetaLogger, object=LOGGER_CONNECTOR_CODE_OBJECT):
         else:
             self.cursor.execute(sql_statement, sql_parameters)
 
-    def executemany(self, sql_statement: str, sql_parameters: tuple or list = None) -> None:
+    def executemany(self, sql_statement: str, sql_parameters: tuple | list = None) -> None:
         try:
             if sql_parameters:  # sql_parameters is list of tuples, each tuple is a row
                 sql_parameters_str = [
@@ -56,8 +60,10 @@ class Cursor(metaclass=MetaLogger, object=LOGGER_CONNECTOR_CODE_OBJECT):
                     values = "(" + values
                 if not values.endswith(")"):
                     values = values + ")"
-                placeholders = "[" + ", ".join([values] * len(sql_parameters)) + "]"
-                concat_params_tuple = tuple([param for tup in sql_parameters_str for param in tup])
+                placeholders = "[" + \
+                    ", ".join([values] * len(sql_parameters)) + "]"
+                concat_params_tuple = tuple(
+                    [param for tup in sql_parameters_str for param in tup])
                 formatted_sql = f"{sql} VALUES {placeholders}" % concat_params_tuple
             else:
                 formatted_sql = sql_statement
@@ -113,7 +119,7 @@ class Cursor(metaclass=MetaLogger, object=LOGGER_CONNECTOR_CODE_OBJECT):
         result = self.cursor.column_names
         return result
 
-    def lastrowid(self) -> int or None:
+    def lastrowid(self) -> int | None:
         """Returns the value generated for an AUTO_INCREMENT column by the previous INSERT or UPDATE statement."""
         result = self.cursor.lastrowid
         return result
@@ -134,7 +140,8 @@ class Cursor(metaclass=MetaLogger, object=LOGGER_CONNECTOR_CODE_OBJECT):
             self.cursor.close()
             self.__is_closed = True
         except Exception as exception:
-            self.logger.error('Unable to close cursor', object={"exception": exception})
+            self.logger.error('Unable to close cursor',
+                              object={"exception": exception})
 
     def is_closed(self) -> bool:
         result = self.__is_closed
