@@ -8,10 +8,11 @@ from logger_local.MetaLogger import MetaLogger
 from user_context_remote.user_context import UserContext
 
 # PyCham on MacOS need . before
-from .constants import DEFAULT_SQL_SELECT_LIMIT, LOGGER_CRUD_ML_CODE_OBJECT
+from database_infrastructure_local.constants import DEFAULT_SQL_SELECT_LIMIT
+from .constants_src import CRUD_ML_CODE_LOGGER_OBJECT, IsTestData
 from .generic_crud import GenericCRUD
 from .table_definition import table_definition
-from .utils import generate_id_column_name, generate_view_name, is_column_in_table
+from .utils import generate_id_column_name, generate_table_name, generate_view_name, is_column_in_table
 
 IS_MAIN_COLUMN_NAME = "is_main"
 
@@ -20,33 +21,39 @@ IS_MAIN_COLUMN_NAME = "is_main"
 #   - is_main in data_ml_dict
 #   - table_definition_table.is_main_column
 #   I'm not sure we need additional parameter.
-class GenericCRUDML(GenericCRUD, metaclass=MetaLogger, object=LOGGER_CRUD_ML_CODE_OBJECT):
+class GenericCRUDML(GenericCRUD, metaclass=MetaLogger, object=CRUD_ML_CODE_LOGGER_OBJECT):
     """A class that provides generic CRUD functionality for tables with multi-language support."""
 
     # TODO: allow overiding all default values in all methods
     # TODO Shall we add same_entity method as parameter?
-    def __init__(self, default_schema_name: str,
-                 default_table_name: str = None, default_view_table_name: str = None,
-                 default_ml_table_name: str = None, default_ml_view_table_name: str = None,
+    def __init__(self, default_entity_name: str = None,
+                 default_schema_name: str = None,
+                 default_table_name: str = None,
+                 default_view_table_name: str = None,
+                 default_ml_table_name: str = None,
+                 default_ml_view_table_name: str = None,
                  default_view_with_deleted_and_test_data: str = None,
                  default_column_name: str = None,  # default_select_clause_value: str = "*"
                  is_main_column_name: str = IS_MAIN_COLUMN_NAME, is_test_data: bool = False) -> None:
         """Initializes the GenericCRUDML class. If connection is not provided,
         a new connection will be created."""
-        self.default_schema_name = default_schema_name
-        self.default_table_name = default_table_name or (default_ml_table_name or "").replace("_ml", "")
+        self.default_schema_name = default_schema_name or default_entity_name
+        self.default_table_name = default_table_name or generate_table_name(entity_name=default_entity_name,
+                                                                                 schema_name=default_schema_name,
+                                                                                 ml_table_name=default_ml_table_name)
         self.default_ml_table_name = default_ml_table_name or self.generate_ml_table_name(default_table_name)
         self.default_ml_view_table_name = default_ml_view_table_name or generate_view_name(self.default_ml_table_name)
         self.default_view_with_deleted_and_test_data = default_view_with_deleted_and_test_data
         self.logger.info("GenericCRUDML.__init__", object={
             "default_ml_table_name": self.default_ml_table_name,
             "default_ml_view_table_name": self.default_ml_view_table_name})
-        super().__init__(default_schema_name=default_schema_name,
+        super().__init__(default_entity_name=default_entity_name,
+                         default_schema_name=default_schema_name,
                          default_table_name=self.default_table_name,
                          default_view_table_name=default_view_table_name,
                          default_view_with_deleted_and_test_data=default_view_with_deleted_and_test_data,
                          default_column_name=default_column_name,
-                         is_test_data=is_test_data)
+                         is_test_data=IsTestData.TEMP_DATA.value)
         self.user_context = UserContext()
         # TODO: we may have to change it to a list when we will have multiple is_main columns
         self.is_main_column_name = is_main_column_name
@@ -128,6 +135,7 @@ class GenericCRUDML(GenericCRUD, metaclass=MetaLogger, object=LOGGER_CRUD_ML_COD
 
             self.connection.commit()
         except Exception as e:
+            # TODO Shall we add retry mechanism?
             self.connection.rollback()
             raise e
         finally:
@@ -513,6 +521,7 @@ class GenericCRUDML(GenericCRUD, metaclass=MetaLogger, object=LOGGER_CRUD_ML_COD
                                              params=(name, lang_code_str))
         return deleted_id
 
+
     @staticmethod
     def generate_ml_table_name(table_name: str) -> str:
         if table_name:
@@ -553,7 +562,7 @@ class GenericCRUDML(GenericCRUD, metaclass=MetaLogger, object=LOGGER_CRUD_ML_COD
         generated_table_name = table_prefix + '_table'
         gcrml = GenericCRUDML(default_schema_name=schema_name,
                               default_ml_table_name=generated_ml_table_name,
-                              is_test_data=True,
+                              is_test_data=IsTestData.TEMP_DATA.value,
                               default_table_name=generated_table_name,
                               default_ml_view_table_name=generated_ml_view_name,
                               is_main_column_name='is_main_title')
