@@ -1,10 +1,10 @@
 from logger_local.MetaLogger import MetaLogger
 
-from .constants import LOGGER_MAPPING_CODE_OBJECT
+from .constants_src import MAPPING_CODE_LOGGER_OBJECT
 from .generic_crud import GenericCRUD
 
 
-class GenericMapping(GenericCRUD, metaclass=MetaLogger, object=LOGGER_MAPPING_CODE_OBJECT):
+class GenericMapping(GenericCRUD, metaclass=MetaLogger, object=MAPPING_CODE_LOGGER_OBJECT):
     def __init__(self, default_schema_name: str = None,
                  default_table_name: str = None,
                  default_view_table_name: str = None,
