@@ -1,7 +1,7 @@
 # TODO Move everything related to sync to separate directory called sync_data_source (preferable with it's own src and tests directories)
 from datetime import datetime
 
-from .constants import UpdateStatus
+from .constants_src import UpdateStatus
 from .generic_crud import GenericCRUD
 
 # TODO Which packages are using it google-contact? contact-csv?
@@ -141,7 +141,7 @@ class SyncConflictResolution(GenericCRUD):
         view_table_name = view_table_name or self.default_view_table_name
         select_clause_value = select_clause_value or self.default_select_clause_value
         remote_last_modified_timestamp: datetime = datetime.strptime(remote_last_modified_timestamp,
-                                                                        '%Y-%m-%d %H:%M:%S')
+                                                                     '%Y-%m-%d %H:%M:%S')
         where = where or self.default_where
         if not view_table_name or not where or not schema_name:
             self.logger.error("view_table_name, where or schema was not provided")
