@@ -10,10 +10,11 @@ from python_sdk_remote.utilities import get_environment_name
 from python_sdk_remote.utilities import our_get_env
 from url_remote.environment_name_enum import EnvironmentName
 
-from .constants import LOGGER_CONNECTOR_CODE_OBJECT
+from .constants_src import LOGGER_CONNECTOR_CODE_OBJECT
 from .table_columns import table_columns
 from .table_definition import table_definition
-from .to_sql_interface import ToSQLInterface
+# from .to_sql_interface import ToSQLInterface
+from database_infrastructure_local.to_sql_interface import ToSQLInterface
 
 logger = Logger.create_logger(object=LOGGER_CONNECTOR_CODE_OBJECT)
 
@@ -201,28 +202,133 @@ def detect_if_is_test_data() -> bool:
     return is_test_data
 
 
-def get_entity_type_by_table_name(table_name: str) -> int | None:
-    """Returns the entity_type_id of the table."""
-    entity_type_id = table_definition.get(table_name, {}).get("entity_type_id1")
-    return entity_type_id
+def get_entity_type_ids_by_table_name(table_name: str) -> int | None:
+    """Get the entity_type_id1 and entity_type_id2 from the table_definition by table_name **IF** the table is many-to-many.
+
+    :param table_name: The name of the table.
+    :return: A tuple of entity_type_id1 and entity_type_id2 if the table is many-to-many, otherwise None.
+    """
+    entity_type_id1 = get_entity_type_id1_by_table_name(table_name)
+    entity_type_id2 = get_entity_type_id2_by_table_name(table_name)
+
+    if entity_type_id1 is not None and entity_type_id2 is not None:
+        return entity_type_id1, entity_type_id2
+    else:
+        logger.warning(f"Table {table_name} is not a many-to-many table, "
+                       f"entity_type_id1: {entity_type_id1}, entity_type_id2: {entity_type_id2}. ")
+        return None
 
 
-def generate_table_name(schema_name: Optional[str]) -> Optional[str]:
-    if schema_name:
+def get_entity_type_id1_by_table_name(table_name: str) -> int | None:
+    """
+    get the entity_type_id1 from the table_definition by table_name.
+
+    :param table_name: The name of the table.
+    :return: The entity_type_id1 of the table, or None if not found.
+    """
+    # TODO Should we search for it in entity_type_table or table_definition?
+
+    entity_type_table = table_definition.get(table_name, {})
+    entity_type_id1 = entity_type_table.get("entity_type_id1")
+
+    return entity_type_id1
+
+
+def get_entity_type_id2_by_table_name(table_name: str) -> int | None:
+    """
+    get the entity_type_id2 from the table_definition by table_name.
+
+    :param table_name: The name of the table.
+    :return: The entity_type_id2 of the table, or None if not found.
+    """
+    entity_type_table = table_definition.get(table_name, {})
+
+    entity_type_id2 = entity_type_table.get("entity_type_id2")
+    return entity_type_id2
+
+
+# def generate_table_name(entity_name: Optional[str],
+#                         schema_name: Optional[str]) -> Optional[str]:
+#     if entity_name:
+#         table_name = entity_name + "_table"
+#         return table_name
+#     if schema_name:
+#         table_name = schema_name + "_table"
+#         return table_name
+
+
+def generate_table_name(entity_name: str = None,
+                        schema_name: str = None,
+                        ml_table_name: str = None) -> str:
+    if ml_table_name:
+        table_name = (ml_table_name or "").replace("_ml", "")
+    elif entity_name:
+        table_name = entity_name + "_table"
+    elif schema_name:
         table_name = schema_name + "_table"
-        return table_name
+    else:
+        table_name = None
 
+    # Append env suffix if needed
+    table_name_with_env = add_env_to_suffix(table_name)
+
+    return table_name_with_env
 
 def generate_view_name(table_name: Optional[str]) -> Optional[str]:
     if table_name:
         view_name = table_name.replace("_table", "_view")
     else:
         view_name = table_name
-    return view_name
+
+    # Append env suffix if needed
+    view_name_with_env = add_env_to_suffix(view_name)
+
+    return view_name_with_env
+
+def add_env_to_suffix(name: Optional[str]) -> Optional[str]:
+    """
+    Add environment name to the suffix of the name and update schema name
+    for specific tables/views in multi-environment databases.
+
+    Examples (env = 'play1'):
+    - profile_table -> test_play1.profile_play1_table
+    - user_view     -> test_play1.user_play1_view
+
+    All other names are returned unchanged.
+    """
+    if name is None:
+        return None
+
+    env_name = get_environment_name()
+    if not env_name:
+        return name
+
+    # Multi-environment entities that require schema + env
+    special_entities = {
+        "test_county_table", "test_county_view",
+        "profile_table", "profile_view",
+        "contact_table", "contact_view",
+        "user_table", "user_view",
+        "person_table", "person_view",
+        "user-external_table", "user-external_view"
+    }
+
+    if name in special_entities:
+        for suffix in ["_table", "_view"]:
+            if name.endswith(suffix):
+                base = name[: -len(suffix)]
+                if not name.endswith(f"_{env_name}{suffix}"):
+                    return f"{base}_{env_name}{suffix}"
+
+    return name
 
 
 def generate_id_column_name(table_name: Optional[str]) -> Optional[str]:
     if table_name:
+        # TODO Why play1_ with _ and dvlp1 without _?
+        if "_play1_" in table_name or "_dvlp1" in table_name:
+            # TODO Why we have environment_name in the table_name in the first place? We should not add the environment_name to the table_name
+            table_name = table_name.replace(f"_{get_environment_name()}_", "_")
         column_name = table_name.replace("_table", "_id")
         return column_name
 
@@ -278,16 +384,31 @@ def replace_view_with_table(view_table_name: str, select_clause_value: str = Non
                 table_name = table  # got a better guess
                 break
     if select_clause_value and select_clause_value != "*":
-        requiered_columns = tuple(col.strip() for col in select_clause_value.split(","))  # if columns are specified
+        required_columns = tuple(col.strip() for col in select_clause_value.split(","))  # if columns are specified
     else:
-        requiered_columns = table_columns.get(view_table_name, [])  # all columns in the view
+        required_columns = table_columns.get(view_table_name, [])  # all columns in the view
 
     # Replace 'ST_X(coordinate)' and 'ST_Y(coordinate)' with 'coordinate'
-    requiered_columns = tuple('coordinate' if col in ('ST_X(coordinate)', 'ST_Y(coordinate)') else
-                              remove_tag(col) for col in requiered_columns)
-    if table_name in table_columns and all(  # if all requiered columns from the view present in the table.
-            remove_tag(col) in table_columns.get(table_name, []) for col in requiered_columns):
-        view_table_name = table_name
+    required_columns = tuple('coordinate' if col in ('ST_X(coordinate)', 'ST_Y(coordinate)') else
+                             remove_tag(col) for col in required_columns)
+
+    # TODO if (is_debug) # Less optimized for runtime, better for debug
+    if table_name in table_columns:
+        all_columns_present = True
+        for col in required_columns:
+            if remove_tag(col) not in table_columns.get(table_name, []):
+                all_columns_present = False
+                logger.warning(f"Column {col} not found in table {table_name}. check the columns in select clause value if they exist in the table.")
+                break
+
+        if all_columns_present:
+            view_table_name = table_name
+
+    # if !is_debug # More optimized for runtime, less for debug
+    # if table_name in table_columns and all(  # if all required columns from the view present in the table.
+    #         remove_tag(col) in table_columns.get(table_name, []) for col in requiered_columns):
+    #     view_table_name = table_name
+
     return view_table_name  # appropriate table not found
 
 
